@@ -103,13 +103,9 @@ class BaseWebDriver(DriverAPI):
     def is_element_present_by_css(self, css_selector, wait_time=None):
         return self.is_element_present(self.find_by_css, css_selector, wait_time)
 
-    is_element_present_by_css_selector = warn_deprecated(is_element_present_by_css, 'is_element_present_by_css_selector')
-
     def is_element_not_present_by_css(self, css_selector, wait_time=None):
         return self.is_element_not_present(self.find_by_css, css_selector, wait_time)
 
-    is_element_not_present_by_css_selector = warn_deprecated(is_element_not_present_by_css, 'is_element_not_present_by_css_selector')
-
     def is_element_present_by_xpath(self, xpath, wait_time=None):
         return self.is_element_present(self.find_by_xpath, xpath, wait_time)
 
@@ -216,8 +212,6 @@ class BaseWebDriver(DriverAPI):
         selector = CSSSelector(css_selector)
         return self.find_by(self.driver.find_elements_by_xpath, selector.path, original_find='css', original_query=css_selector)
 
-    find_by_css_selector = warn_deprecated(find_by_css, 'find_by_css_selector')
-
     def find_by_xpath(self, xpath, original_find=None, original_query=None):
         original_find = original_find or "xpath"
         original_query = original_query or xpath
@@ -239,9 +233,26 @@ class BaseWebDriver(DriverAPI):
         field = self.find_by_name(name).first
         field.value = value
 
-    fill_in = warn_deprecated(fill, 'fill_in')
     attach_file = fill
 
+    def fill_form(self, field_values):
+        for name, value in field_values.items():
+            elements = self.find_by_name(name)
+            element = elements.first
+            if element['type'] == 'text':
+                element.value = value
+            elif element['type'] == 'checkbox':
+                if value:
+                    element.check()
+                else:
+                    element.uncheck()
+            elif element['type'] == 'radio':
+                for field in elements:
+                    if field.value == value:
+                        field.click()
+            elif element._element.tag_name == 'select':
+                element.find_by_value(value).first._element.click()
+
     def type(self, name, value, slowly=False):
         element = self.driver.find_element_by_css_selector('input[name="%s"]' % name)
         if slowly:
@@ -303,7 +314,8 @@ class WebDriverElement(ElementAPI):
             return self._element.text
 
     def _set_value(self, value):
-        self._element.clear()
+        if  self._element.get_attribute('type') != 'file':
+            self._element.clear()
         self._element.send_keys(value)
 
     value = property(_get_value, _set_value)
@@ -312,6 +324,16 @@ class WebDriverElement(ElementAPI):
     def text(self):
         return self._element.text
 
+    def fill(self, value):
+        self.value = value
+
+    def type(self, value, slowly=False):
+        if slowly:
+            return TypeIterator(self._element, value)
+
+        self._element.send_keys(value)
+        return value
+
     def click(self):
         self._element.click()
 
@@ -429,4 +451,3 @@ class AlertElement(object):
 
     def __exit__(self, type, value, traceback):
         pass
-
